const colors = {
  black: '#000000',
  white: '#FFFFFF',
  default: '#F1F5F9',
  checkMark: '#37C4AA',
  success: '#29C4A9',
  successAlt: '#70C3A9',
  primary: '#6C2EB9',
  primaryAlt: '#7D3BCF',
  info: '#2B87DA',
  infoAlt: '#00B9DC',
  danger: '#EF5555',
  dangerAlt: '#EB3D00',
  inverse: '#4C5866',
  warning: '#FF9232',
  warningAlt: '#F3CB57',
  globalitem: '#97d000',
  optionTabIcon: '#BEC9D5',
  activeTabIcon: '#2B96E1',
  abTestingTimeFilter: '#A1A9B2',
  disabledSubject: '#E1E4EA',
  inactiveGrey: '#BEC9D6',
  shuttleGrey: '#5C6978',
  fiord: '#3E5062',
  uploadImagePreview: '#333B44',
  bfbPreviewActive: '#5C6979',
  bfbPreview: '#9FA5AC',
  enabledDeviceIcon: '#42E1A7',
  disabledDeviceIcon: '#EF5555',
  coreModalButtonBlue: '#008BDA',
  historyActiveButton: '#99CF02',
  uiActiveIcon: '#4191DE',
  uiInactiveIcon: '#bec9d6',
  moduleItemControlIcons: '#737e89',
  selectPositionGray: '#E6ECF2',
  cadetBlue: '#A2B0C1',
  layerBackground: '#f0f5f9',
  activeCloud: '#0088E1',
  activeFav: '#FF454E',
  button: '#a3b0c2',
};

export default colors;
